@@ -10,13 +10,8 @@ from upy.utils import clean_cache
 from imagekit.models import ImageSpecField
 from imagekit.processors import ResizeToFit
 
-def list_apps():
-    """
-    it returns a list of tuples with the name of all installed apps with admin's registration.
-    """
-    list_apps = []
-    for app in settings.INSTALLED_APPS:
-        if app not in ['django.contrib.contenttypes',
+def verifyApp(app):
+    return app in ['django.contrib.contenttypes',
                         'django.contrib.sessions',
                         'django.contrib.messages',
                         'django.contrib.admin',
@@ -26,12 +21,38 @@ def list_apps():
                         'upy',
                         'upy.contrib.ckeditor',
                         'upy.contrib.colors',
-                        'upy.contrib.language']:
+                        'upy.contrib.language']
+        
+
+def list_apps():
+    """
+    it returns a list of tuples with the name of all installed apps with admin's registration.
+    """
+    list_apps = []
+    for app in settings.INSTALLED_APPS:
+        if not verifyApp(app): 
             try:
                 CustomApp.objects.get(application=app.split(".")[-1].title())
             except:
                 list_apps.append([app.split(".")[-1].title()]*2)
     return list_apps 
+
+def list_models():
+    """
+    It returns a list of tuple with the name of all models in installed apps
+    """
+    list_models = []
+    for app in settings.INSTALLED_APPS:
+        if not verifyApp(app):
+            list_models_app = []
+            for m in models.get_models(models.get_app(app.split(".")[-1])):
+                try:
+                    CustomModel.objects.get(model=m.__name__)
+                except:
+                    list_models_app.append([m._meta.verbose_name_plural]*2)
+            list_models.append((app.split(".")[-1].title(),list_models_app))
+    return list_models
+
 class CustomAdmin(models.Model):
     """
     This object define parameters to customize admin layout. It has sense if you use only a record 
@@ -93,14 +114,18 @@ class CustomAdmin(models.Model):
     use_log_sidebar = models.BooleanField(default = False, help_text = _(u"Check it if you want use log sidebar in index template."), 
                                        verbose_name = _(u"Use log sidebar"))
     view_mode = models.CharField(max_length = 250, null = True, blank = True, 
-                                 choices = (('use_custom_app',_('use_custom_app')),
-                                            ('use_app_icons',_('use_app_icons'))), 
+                                 choices = (('use_custom_app',_('Use custom app system')),
+                                            ('use_app_icons',_("Use apps' icons system")),
+                                            ('use_model_icons',_("Use models' icons system in index")),
+                                            ('use_inner_model_icons',_("Use models' icons system in app template"))), 
                                  help_text = _(u"Choose the view mode"), 
                                  verbose_name = _(u"View mode"))
     autocomplete_app_list = models.BooleanField(default = True, 
         help_text = _(u"Check it if you want complete the custom app list with the default app list."), 
         verbose_name = _(u"Autocomplete App list"))
-    
+    autocomplete_models_list = models.BooleanField(default = True, 
+        help_text = _(u"Check it if you want complete the custom models list with the default models list."), 
+        verbose_name = _(u"Autocomplete model list"))
     @property
     def customization(self):
         """
@@ -155,32 +180,6 @@ class CustomApp(PositionImage):
     show_models = models.BooleanField(default=True, 
         help_text = _(u"If use_app_icons is False in Customadmin, you can choose wheter or not show the model list."), 
         verbose_name = _(u"Show models"))
-    '''
-    tengo questo commento in attesa di sviluppare il resize dinamico
-        
-    display_width = models.PositiveIntegerField(default = 0)
-    display_height = models.PositiveIntegerField(default = 0)
-    #app_group = ManyToMany to a group. Future feature to regroup apps in different boxes.
-       
-    
-    def save(self, *args, **kwargs):
-        
-        print "QQQQQQQQQQQQQQQQQQQQQq sono in customadmin.models.AppIcon.save - prima"
-        print "111", dir(self.display_image)
-        #print self.display_image.height
-        #print self.display_image.width
-        print "222", self.display_image._process_content
-        print "333", dir(self.display_image._process_content)
-        print "444", self.display_image._process_content.im_class
-        print "555", self.display_image._process_content.im_func
-        print "666", self.display_image._process_content.im_self
-        print "777", dir(self.display_image._process_content.im_func)
-        print "888", self.display_image._process_content.im_func.func_code
-        print "999", self.display_image._process_content.im_func.func_name
-        #if self.display_width > 0 : self.display_image.processors[0].width = self.display_width
-        #if self.display_height > 0: self.display_image.processors[0].height = self.display_height
-        super(AppIcon,self).save( *args, **kwargs)
-    '''
     
     def __unicode__(self):
         return u"%s" % (self.application)
@@ -210,4 +209,24 @@ class CustomLink(PositionImage):
     class Meta:
         verbose_name = _(u"Custom Link")
         verbose_name_plural = _(u"Custom Link")
-        ordering = ['position']
\ No newline at end of file
+        ordering = ['position']
+
+class CustomModel(PositionImage):
+    """
+    This object links models in  installed_apps with an icon to use if CustomAdmin.view_mode == "use_model_icons" or CustomAdmin.view_mode == "use_inner_model_icons"
+    """
+    model = models.CharField(max_length = 250, 
+                                   unique=True, help_text = _(u"Select a model"), 
+                                   verbose_name = _(u"Model"))
+    image = ImageSpecField([ResizeToFit(50, 50)], 
+                           image_field='original_image', 
+                           format='png')
+    
+    def __unicode__(self):
+        return u"%s" % (self.model)
+    
+    class Meta:
+        verbose_name = _(u"Custom Model")
+        verbose_name_plural = _(u"Custom Models")
+        ordering = ['position']
+ 
